/*
   FNT - SQL-backend for PostgreSQL - transactions handle functions

   Copyright (C) 2009 Free Software Foundation, Inc.

   Written by:
   Slava Zanko <slavazanko@gmail.com>


   This file is part of the FIDO New Technology.

   FIDO New Technology is free software: you can redistribute it and/or 
   modify it under the terms of the GNU General Public License as published 
   by the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifdef HAVE_CONFIG_H
#	include <config.h>
#endif

#include <libpq-fe.h>
#include <stdlib.h>

#include "../include/global.h"

#include "../include/types.h"
#include "../include/error.h"
#include "../include/plugin.h"
#include "../include/sql.h"

#include "main.h"

/*** global variables **************************************************/

/*** file scope macro definitions **************************************/

/*** file scope type declarations **************************************/

/*** file scope variables **********************************************/

/*** file scope functions **********************************************/

/*** public functions **************************************************/


DLLEXPORT bool
begin_transaction (fnt_sql_connect_t * sql_connect)
{
    fnt_sql_query_t *sql_query;

    sql_query = fnt_sql_query (sql_connect, "BEGIN TRANSACTION");
    if (sql_query == NULL)
    {
	fnt_error_push (FNT_MODULE_sql, FNT_SQL_E_DRIVER,
			_("Pgsql - fail to start transaction"));
	return false;
    }
    return fnt_sql_queryClear (&sql_query);
}

DLLEXPORT bool
rollback_transaction (fnt_sql_connect_t * sql_connect)
{
    fnt_sql_query_t *sql_query;

    sql_query = fnt_sql_query (sql_connect, "ROLLBACK TRANSACTION");
    if (sql_query == NULL)
    {
	fnt_error_push (FNT_MODULE_sql, FNT_SQL_E_DRIVER,
			_("Pgsql - fail to rollback transaction"));
	return false;
    }
    return fnt_sql_queryClear (&sql_query);
}

DLLEXPORT bool
commit_transaction (fnt_sql_connect_t * sql_connect)
{
    fnt_sql_query_t *sql_query;

    sql_query = fnt_sql_query (sql_connect, "COMMIT TRANSACTION");
    if (sql_query == NULL)
    {
	fnt_error_push (FNT_MODULE_sql, FNT_SQL_E_DRIVER,
			_("Pgsql - fail to commit transaction"));
	return false;
    }
    return fnt_sql_queryClear (&sql_query);
}
